==> kubernetes-model-batch-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/batch/v1/PodFailurePolicyFluentImpl.java <==
package io.fabric8.kubernetes.api.model.batch.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodFailurePolicyFluentImpl<A extends PodFailurePolicyFluent<A>> extends BaseFluent<A> implements PodFailurePolicyFluent<A>{
  public PodFailurePolicyFluentImpl() {
  }
  public PodFailurePolicyFluentImpl(PodFailurePolicy instance) {
    this.withRules(instance.getRules()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private ArrayList<PodFailurePolicyRuleBuilder> rules = new ArrayList<PodFailurePolicyRuleBuilder>();
  private Map<String,Object> additionalProperties;
  public A addToRules(Integer index,PodFailurePolicyRule item) {
    if (this.rules == null) {this.rules = new ArrayList<PodFailurePolicyRuleBuilder>();}
    PodFailurePolicyRuleBuilder builder = new PodFailurePolicyRuleBuilder(item);_visitables.get("rules").add(index >= 0 ? index : _visitables.get("rules").size(), builder);this.rules.add(index >= 0 ? index : rules.size(), builder); return (A)this;
  }
  public A setToRules(Integer index,PodFailurePolicyRule item) {
    if (this.rules == null) {this.rules = new ArrayList<PodFailurePolicyRuleBuilder>();}
    PodFailurePolicyRuleBuilder builder = new PodFailurePolicyRuleBuilder(item);
    if (index < 0 || index >= _visitables.get("rules").size()) { _visitables.get("rules").add(builder); } else { _visitables.get("rules").set(index, builder);}
    if (index < 0 || index >= rules.size()) { rules.add(builder); } else { rules.set(index, builder);}
     return (A)this;
  }
  public A addToRules(io.fabric8.kubernetes.api.model.batch.v1.PodFailurePolicyRule... items) {
    if (this.rules == null) {this.rules = new ArrayList<PodFailurePolicyRuleBuilder>();}
    for (PodFailurePolicyRule item : items) {PodFailurePolicyRuleBuilder builder = new PodFailurePolicyRuleBuilder(item);_visitables.get("rules").add(builder);this.rules.add(builder);} return (A)this;
  }
  public A addAllToRules(Collection<PodFailurePolicyRule> items) {
    if (this.rules == null) {this.rules = new ArrayList<PodFailurePolicyRuleBuilder>();}
    for (PodFailurePolicyRule item : items) {PodFailurePolicyRuleBuilder builder = new PodFailurePolicyRuleBuilder(item);_visitables.get("rules").add(builder);this.rules.add(builder);} return (A)this;
  }
  public A removeFromRules(io.fabric8.kubernetes.api.model.batch.v1.PodFailurePolicyRule... items) {
    for (PodFailurePolicyRule item : items) {PodFailurePolicyRuleBuilder builder = new PodFailurePolicyRuleBuilder(item);_visitables.get("rules").remove(builder);if (this.rules != null) {this.rules.remove(builder);}} return (A)this;
  }
  public A removeAllFromRules(Collection<PodFailurePolicyRule> items) {
    for (PodFailurePolicyRule item : items) {PodFailurePolicyRuleBuilder builder = new PodFailurePolicyRuleBuilder(item);_visitables.get("rules").remove(builder);if (this.rules != null) {this.rules.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromRules(Predicate<PodFailurePolicyRuleBuilder> predicate) {
    if (rules == null) return (A) this;
    final Iterator<PodFailurePolicyRuleBuilder> each = rules.iterator();
    final List visitables = _visitables.get("rules");
    while (each.hasNext()) {
      PodFailurePolicyRuleBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PodFailurePolicyRule> getRules() {
    return rules != null ? build(rules) : null;
  }
  public List<PodFailurePolicyRule> buildRules() {
    return rules != null ? build(rules) : null;
  }
  public PodFailurePolicyRule buildRule(Integer index) {
    return this.rules.get(index).build();
  }
  public PodFailurePolicyRule buildFirstRule() {
    return this.rules.get(0).build();
  }
  public PodFailurePolicyRule buildLastRule() {
    return this.rules.get(rules.size() - 1).build();
  }
  public PodFailurePolicyRule buildMatchingRule(Predicate<PodFailurePolicyRuleBuilder> predicate) {
    for (PodFailurePolicyRuleBuilder item: rules) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingRule(Predicate<PodFailurePolicyRuleBuilder> predicate) {
    for (PodFailurePolicyRuleBuilder item: rules) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withRules(List<PodFailurePolicyRule> rules) {
    if (this.rules != null) { _visitables.get("rules").removeAll(this.rules);}
    if (rules != null) {this.rules = new ArrayList(); for (PodFailurePolicyRule item : rules){this.addToRules(item);}} else { this.rules = null;} return (A) this;
  }
  public A withRules(io.fabric8.kubernetes.api.model.batch.v1.PodFailurePolicyRule... rules) {
    if (this.rules != null) {this.rules.clear();}
    if (rules != null) {for (PodFailurePolicyRule item :rules){ this.addToRules(item);}} return (A) this;
  }
  public Boolean hasRules() {
    return rules != null && !rules.isEmpty();
  }
  public PodFailurePolicyFluent.RulesNested<A> addNewRule() {
    return new PodFailurePolicyFluentImpl.RulesNestedImpl();
  }
  public PodFailurePolicyFluent.RulesNested<A> addNewRuleLike(PodFailurePolicyRule item) {
    return new PodFailurePolicyFluentImpl.RulesNestedImpl(-1, item);
  }
  public PodFailurePolicyFluent.RulesNested<A> setNewRuleLike(Integer index,PodFailurePolicyRule item) {
    return new PodFailurePolicyFluentImpl.RulesNestedImpl(index, item);
  }
  public PodFailurePolicyFluent.RulesNested<A> editRule(Integer index) {
    if (rules.size() <= index) throw new RuntimeException("Can't edit rules. Index exceeds size.");
    return setNewRuleLike(index, buildRule(index));
  }
  public PodFailurePolicyFluent.RulesNested<A> editFirstRule() {
    if (rules.size() == 0) throw new RuntimeException("Can't edit first rules. The list is empty.");
    return setNewRuleLike(0, buildRule(0));
  }
  public PodFailurePolicyFluent.RulesNested<A> editLastRule() {
    int index = rules.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last rules. The list is empty.");
    return setNewRuleLike(index, buildRule(index));
  }
  public PodFailurePolicyFluent.RulesNested<A> editMatchingRule(Predicate<PodFailurePolicyRuleBuilder> predicate) {
    int index = -1;
    for (int i=0;i<rules.size();i++) { 
    if (predicate.test(rules.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching rules. No match found.");
    return setNewRuleLike(index, buildRule(index));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodFailurePolicyFluentImpl that = (PodFailurePolicyFluentImpl) o;
    if (rules != null ? !rules.equals(that.rules) :that.rules != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(rules,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (rules != null && !rules.isEmpty()) { sb.append("rules:"); sb.append(rules + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class RulesNestedImpl<N> extends PodFailurePolicyRuleFluentImpl<PodFailurePolicyFluent.RulesNested<N>> implements PodFailurePolicyFluent.RulesNested<N>,Nested<N>{
    RulesNestedImpl(Integer index,PodFailurePolicyRule item) {
      this.index = index;
      this.builder = new PodFailurePolicyRuleBuilder(this, item);
    }
    RulesNestedImpl() {
      this.index = -1;
      this.builder = new PodFailurePolicyRuleBuilder(this);
    }
    PodFailurePolicyRuleBuilder builder;
    Integer index;
    public N and() {
      return (N) PodFailurePolicyFluentImpl.this.setToRules(index,builder.build());
    }
    public N endRule() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-batch-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/batch/v1/PodFailurePolicyFluentImpl.java <==
package io.fabric8.kubernetes.api.model.batch.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodFailurePolicyFluentImpl<A extends PodFailurePolicyFluent<A>> extends BaseFluent<A> implements PodFailurePolicyFluent<A>{
  public PodFailurePolicyFluentImpl() {
  }
  public PodFailurePolicyFluentImpl(PodFailurePolicy instance) {
    if (instance != null) {
      this.withRules(instance.getRules());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ArrayList<PodFailurePolicyRuleBuilder> rules = new ArrayList<PodFailurePolicyRuleBuilder>();
  private Map<String,Object> additionalProperties;
  public A addToRules(int index,PodFailurePolicyRule item) {
    if (this.rules == null) {this.rules = new ArrayList<PodFailurePolicyRuleBuilder>();}
    PodFailurePolicyRuleBuilder builder = new PodFailurePolicyRuleBuilder(item);
    if (index < 0 || index >= rules.size()) { _visitables.get("rules").add(builder); rules.add(builder); } else { _visitables.get("rules").add(index, builder); rules.add(index, builder);}
    return (A)this;
  }
  public A setToRules(int index,PodFailurePolicyRule item) {
    if (this.rules == null) {this.rules = new ArrayList<PodFailurePolicyRuleBuilder>();}
    PodFailurePolicyRuleBuilder builder = new PodFailurePolicyRuleBuilder(item);
    if (index < 0 || index >= rules.size()) { _visitables.get("rules").add(builder); rules.add(builder); } else { _visitables.get("rules").set(index, builder); rules.set(index, builder);}
    return (A)this;
  }
  public A addToRules(io.fabric8.kubernetes.api.model.batch.v1.PodFailurePolicyRule... items) {
    if (this.rules == null) {this.rules = new ArrayList<PodFailurePolicyRuleBuilder>();}
    for (PodFailurePolicyRule item : items) {PodFailurePolicyRuleBuilder builder = new PodFailurePolicyRuleBuilder(item);_visitables.get("rules").add(builder);this.rules.add(builder);} return (A)this;
  }
  public A addAllToRules(Collection<PodFailurePolicyRule> items) {
    if (this.rules == null) {this.rules = new ArrayList<PodFailurePolicyRuleBuilder>();}
    for (PodFailurePolicyRule item : items) {PodFailurePolicyRuleBuilder builder = new PodFailurePolicyRuleBuilder(item);_visitables.get("rules").add(builder);this.rules.add(builder);} return (A)this;
  }
  public A removeFromRules(io.fabric8.kubernetes.api.model.batch.v1.PodFailurePolicyRule... items) {
    for (PodFailurePolicyRule item : items) {PodFailurePolicyRuleBuilder builder = new PodFailurePolicyRuleBuilder(item);_visitables.get("rules").remove(builder);if (this.rules != null) {this.rules.remove(builder);}} return (A)this;
  }
  public A removeAllFromRules(Collection<PodFailurePolicyRule> items) {
    for (PodFailurePolicyRule item : items) {PodFailurePolicyRuleBuilder builder = new PodFailurePolicyRuleBuilder(item);_visitables.get("rules").remove(builder);if (this.rules != null) {this.rules.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromRules(Predicate<PodFailurePolicyRuleBuilder> predicate) {
    if (rules == null) return (A) this;
    final Iterator<PodFailurePolicyRuleBuilder> each = rules.iterator();
    final List visitables = _visitables.get("rules");
    while (each.hasNext()) {
      PodFailurePolicyRuleBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PodFailurePolicyRule> getRules() {
    return rules != null ? build(rules) : null;
  }
  public List<PodFailurePolicyRule> buildRules() {
    return rules != null ? build(rules) : null;
  }
  public PodFailurePolicyRule buildRule(int index) {
    return this.rules.get(index).build();
  }
  public PodFailurePolicyRule buildFirstRule() {
    return this.rules.get(0).build();
  }
  public PodFailurePolicyRule buildLastRule() {
    return this.rules.get(rules.size() - 1).build();
  }
  public PodFailurePolicyRule buildMatchingRule(Predicate<PodFailurePolicyRuleBuilder> predicate) {
    for (PodFailurePolicyRuleBuilder item: rules) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingRule(Predicate<PodFailurePolicyRuleBuilder> predicate) {
    for (PodFailurePolicyRuleBuilder item: rules) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withRules(List<PodFailurePolicyRule> rules) {
    if (this.rules != null) { _visitables.get("rules").clear();}
    if (rules != null) {this.rules = new ArrayList(); for (PodFailurePolicyRule item : rules){this.addToRules(item);}} else { this.rules = null;} return (A) this;
  }
  public A withRules(io.fabric8.kubernetes.api.model.batch.v1.PodFailurePolicyRule... rules) {
    if (this.rules != null) {this.rules.clear(); _visitables.remove("rules"); }
    if (rules != null) {for (PodFailurePolicyRule item :rules){ this.addToRules(item);}} return (A) this;
  }
  public Boolean hasRules() {
    return rules != null && !rules.isEmpty();
  }
  public PodFailurePolicyFluentImpl.RulesNested<A> addNewRule() {
    return new PodFailurePolicyFluentImpl.RulesNestedImpl();
  }
  public PodFailurePolicyFluentImpl.RulesNested<A> addNewRuleLike(PodFailurePolicyRule item) {
    return new PodFailurePolicyFluentImpl.RulesNestedImpl(-1, item);
  }
  public PodFailurePolicyFluentImpl.RulesNested<A> setNewRuleLike(int index,PodFailurePolicyRule item) {
    return new PodFailurePolicyFluentImpl.RulesNestedImpl(index, item);
  }
  public PodFailurePolicyFluentImpl.RulesNested<A> editRule(int index) {
    if (rules.size() <= index) throw new RuntimeException("Can't edit rules. Index exceeds size.");
    return setNewRuleLike(index, buildRule(index));
  }
  public PodFailurePolicyFluentImpl.RulesNested<A> editFirstRule() {
    if (rules.size() == 0) throw new RuntimeException("Can't edit first rules. The list is empty.");
    return setNewRuleLike(0, buildRule(0));
  }
  public PodFailurePolicyFluentImpl.RulesNested<A> editLastRule() {
    int index = rules.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last rules. The list is empty.");
    return setNewRuleLike(index, buildRule(index));
  }
  public PodFailurePolicyFluentImpl.RulesNested<A> editMatchingRule(Predicate<PodFailurePolicyRuleBuilder> predicate) {
    int index = -1;
    for (int i=0;i<rules.size();i++) { 
    if (predicate.test(rules.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching rules. No match found.");
    return setNewRuleLike(index, buildRule(index));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodFailurePolicyFluentImpl that = (PodFailurePolicyFluentImpl) o;
    if (!java.util.Objects.equals(rules, that.rules)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(rules,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (rules != null) { sb.append("rules:"); sb.append(rules + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class RulesNestedImpl<N> extends PodFailurePolicyRuleFluentImpl<PodFailurePolicyFluentImpl.RulesNested<N>> implements PodFailurePolicyFluentImpl.RulesNested<N>,Nested<N>{
    RulesNestedImpl(int index,PodFailurePolicyRule item) {
      this.index = index;
      this.builder = new PodFailurePolicyRuleBuilder(this, item);
    }
    RulesNestedImpl() {
      this.index = -1;
      this.builder = new PodFailurePolicyRuleBuilder(this);
    }
    PodFailurePolicyRuleBuilder builder;
    int index;
    public N and() {
      return (N) PodFailurePolicyFluentImpl.this.setToRules(index,builder.build());
    }
    public N endRule() {
      return and();
    }
    
  }
  
}
